@@ -11,12 +11,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.core import urlresolvers
 from django import http as http_response
 from django.template import defaultfilters as filters
+from django import urls
 from django.utils import http
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import tables
 from horizon.tabs import base as tabs_base
@@ -45,9 +45,14 @@ class CreateCluster(tables.LinkAction):
     icon = "plus"
 
     def get_link_url(self, datum):
-        base_url = urlresolvers.reverse(self.url)
+        base_url = urls.reverse(self.url)
 
-        params = http.urlencode({"hadoop_version": datum.hadoop_version,
+        if saharaclient.VERSIONS.active == '2':
+            version_attr = "plugin_version"
+        else:
+            version_attr = "hadoop_version"
+        params = http.urlencode({"hadoop_version":
+                                 getattr(datum, version_attr),
                                  "plugin_name": datum.plugin_name,
                                  "cluster_template_id": datum.id})
         return "?".join([base_url, params])
@@ -87,7 +92,7 @@ class EditTemplate(tables.LinkAction):
 class DeleteTemplate(tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Template",
             u"Delete Templates",
             count
@@ -95,7 +100,7 @@ class DeleteTemplate(tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Deleted Template",
             u"Deleted Templates",
             count
@@ -172,7 +177,11 @@ class ClusterTemplatesTable(sahara_table.SaharaPaginateTabbedTable):
                                "clusters:ct-details"))
     plugin_name = tables.Column("plugin_name",
                                 verbose_name=_("Plugin"))
-    hadoop_version = tables.Column("hadoop_version",
+    if saharaclient.VERSIONS.active == '2':
+        version_attr = "plugin_version"
+    else:
+        version_attr = "hadoop_version"
+    hadoop_version = tables.Column(version_attr,
                                    verbose_name=_("Version"))
     node_groups = tables.Column(render_node_groups,
                                 verbose_name=_("Node Groups"),
