@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.urls import reverse
+from django.urls import reverse_lazy
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
