@@ -13,8 +13,8 @@
 
 import json
 
-from django.core import urlresolvers
-from django.utils.translation import ugettext_lazy as _
+from django import urls
+from django.utils.translation import gettext_lazy as _
 from saharaclient.api import base as api_base
 
 from horizon import exceptions
@@ -66,7 +66,7 @@ class CreateClusterTemplate(workflows.Workflow):
     default_steps = (SelectPlugin, )
 
     def get_success_url(self):
-        url = urlresolvers.reverse(self.success_url)
+        url = urls.reverse(self.success_url)
         return url
 
 
@@ -171,7 +171,7 @@ class ConfigureNodegroupsAction(workflows.Action):
         req = request.GET.copy()
         req.update(request.POST)
         plugin = req.get("plugin_name")
-        version = req.get("hadoop_version")
+        version = req.get("hadoop_version", None) or req["plugin_version"]
         if plugin and not version:
             version_name = plugin + "_version"
             version = req.get(version_name)
@@ -328,7 +328,7 @@ class ConfigureClusterTemplate(whelpers.ServiceParametersWorkflow,
                      ConfigureNodegroups)
 
     def __init__(self, request, context_seed, entry_point, *args, **kwargs):
-        ConfigureClusterTemplate._cls_registry = set([])
+        ConfigureClusterTemplate._cls_registry = []
 
         hlps = helpers.Helpers(request)
         plugin, hadoop_version = whelpers.\
