@@ -13,7 +13,7 @@
 
 import json
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from saharaclient.api import base as api_base
 
 from horizon import exceptions
@@ -40,7 +40,7 @@ class ScaleCluster(cl_create_flow.ConfigureCluster,
     default_steps = (NodeGroupsStep, )
 
     def __init__(self, request, context_seed, entry_point, *args, **kwargs):
-        ScaleCluster._cls_registry = set([])
+        ScaleCluster._cls_registry = []
 
         self.success_message = _("Scaled cluster successfully started.")
 
@@ -48,7 +48,11 @@ class ScaleCluster(cl_create_flow.ConfigureCluster,
         try:
             cluster = saharaclient.cluster_get(request, cluster_id)
             plugin = cluster.plugin_name
-            hadoop_version = cluster.hadoop_version
+            if saharaclient.VERSIONS.active == '2':
+                version_attr = 'plugin_version'
+            else:
+                version_attr = 'hadoop_version'
+            hadoop_version = getattr(cluster, version_attr)
 
             # Initialize deletable node groups.
             deletable = dict()
@@ -58,7 +62,7 @@ class ScaleCluster(cl_create_flow.ConfigureCluster,
             request.GET.update({
                 "cluster_id": cluster_id,
                 "plugin_name": plugin,
-                "hadoop_version": hadoop_version,
+                version_attr: hadoop_version,
                 "deletable": deletable
             })
 
