@@ -13,11 +13,11 @@
 
 from oslo_log import log as logging
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import tabs
-from openstack_dashboard.api import network
+from openstack_dashboard.api import neutron
 from openstack_dashboard.api import nova
 
 from sahara_dashboard.api import sahara as saharaclient
@@ -98,13 +98,19 @@ class GeneralTab(tabs.Tab):
         security_groups = helpers.get_security_groups(
             request, template.security_groups)
 
+        if getattr(template, 'boot_from_volume', None) is None:
+            show_bfv = False
+        else:
+            show_bfv = True
+
         return {"template": template, "flavor": flavor,
                 "floating_ip_pool_name": floating_ip_pool_name,
                 "base_image_name": base_image_name,
-                "security_groups": security_groups}
+                "security_groups": security_groups,
+                "show_bfv": show_bfv}
 
     def _get_floating_ip_pool_name(self, request, pool_id):
-        pools = [pool for pool in network.floating_ip_pools_list(
+        pools = [pool for pool in neutron.floating_ip_pools_list(
             request) if pool.id == pool_id]
 
         return pools[0].name if pools else pool_id
