@@ -11,7 +11,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from saharaclient.api import base as api_base
 
 from horizon import exceptions
@@ -79,7 +79,7 @@ class EditNodegroupTemplate(copy_flow.CopyNodegroupTemplate):
 
             image_id = context["general_image"] or None
 
-            saharaclient.nodegroup_template_update(
+            args_dict = dict(
                 request=request,
                 ngt_id=self.template_id,
                 name=context["general_nodegroup_name"],
@@ -104,6 +104,22 @@ class EditNodegroupTemplate(copy_flow.CopyNodegroupTemplate):
                 is_public=context['general_is_public'],
                 is_protected=context['general_is_protected'],
                 image_id=image_id)
+
+            if (saharaclient.VERSIONS.active == '2'
+                    and context["general_boot_storage"] == "cinder_volume"):
+                args_dict['boot_from_volume'] = True
+                args_dict['boot_volume_type'] = (
+                    context["general_boot_volume_type"] or None
+                )
+                args_dict['boot_volume_availability_zone'] = (
+                    context["general_boot_volume_availability_zone"] or None
+                )
+                args_dict['boot_volume_local_to_instance'] = (
+                    context["general_boot_volume_local_to_instance"]
+                )
+
+            saharaclient.nodegroup_template_update(**args_dict)
+
             return True
         except api_base.APIException as e:
             self.error_description = str(e.message)
