@@ -11,7 +11,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import tabs
 
@@ -23,9 +23,11 @@ from sahara_dashboard.content.data_processing.clusters.image_registry \
     import tabs as image_registry_tabs
 from sahara_dashboard.content.data_processing.clusters.nodegroup_templates \
     import tabs as node_group_templates_tabs
+from sahara_dashboard.content.data_processing.tabs \
+    import PaginationFriendlyTabGroup
 
 
-class ClusterTabs(tabs.TabGroup):
+class ClusterTabs(PaginationFriendlyTabGroup):
     slug = "cluster_tabs"
     tabs = (clusters_tabs.ClustersTab,
             cluster_templates_tabs.ClusterTemplatesTab,
