@@ -17,9 +17,9 @@ import uuid
 from django.forms import widgets
 from django import template
 from django.template import defaultfilters
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -333,7 +333,7 @@ class JobBinaryCreateForm(forms.SelfHandlingForm):
             tmpl = template.loader.get_template(self.help_text_template)
             text += tmpl.render(extra_context, self.request)
         else:
-            text += defaultfilters.linebreaks(force_text(self.help_text))
+            text += defaultfilters.linebreaks(force_str(self.help_text))
         return defaultfilters.safe(text)
 
     class Meta(object):
