@@ -15,7 +15,7 @@ from oslo_log import log as logging
 
 from django.core.exceptions import ValidationError
 from django.utils import safestring
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
